@@ -11,7 +11,7 @@
 
 #include <dune/localfunctions/test/test-localfe.hh>
 
-int main(int argc, char** argv) try
+int main(int argc, char** argv)
 {
   bool success = true;
 
@@ -23,8 +23,3 @@ int main(int argc, char** argv) try
 
   return success ? 0 : 1;
 }
-catch (Dune::Exception e)
-{
-  std::cout << e.what() << std::endl;
-  return 1;
-}
