@@ -10,6 +10,7 @@
 
 #include <dune/geometry/type.hh>
 #include <dune/localfunctions/common/virtualinterface.hh>
+#include <dune/localfunctions/common/virtualwrappers.hh>
 
 #include <dune/localfunctions/lagrange/p0.hh>
 #include <dune/localfunctions/lagrange/p1.hh>
@@ -125,7 +126,7 @@ void testLocalFiniteElement(const LocalFiniteElementVirtualInterface<T>* localFi
 
 }
 
-int main (int argc, char *argv[]) try
+int main (int argc, char *argv[])
 {
 
   typedef Dune::P1LocalFiniteElement<double, double, 2>::Traits::LocalBasisType::Traits LBTraits;
@@ -157,8 +158,3 @@ int main (int argc, char *argv[]) try
   return 0;
 
 }
-catch (Exception e) {
-
-  std::cout << e << std::endl;
-  return 1;
-}
